=== modified file 'NEWS'
--- NEWS	2007-04-11 04:26:23 +0000
+++ NEWS	2007-04-13 01:57:12 +0000
@@ -41,10 +41,6 @@
       bzrlib/transport/remote.py contains just the Transport classes that used
       to be in bzrlib/transport/smart.py.  (Andrew Bennetts)
  
-    * ``LockableFiles.lock_write()`` now accepts a ``token`` keyword argument,
-      so that a seperate LockableFiles instance can share a lock if it has the
-      right token.  (Andrew Bennetts, Robert Collins)
-
     * The Repository API ``make_working_trees`` is now permitted to return
       False when ``set_make_working_trees`` is not implemented - previously
       an unimplemented ``set_make_working_trees`` implied the result True
@@ -52,6 +48,11 @@
       smart server, where it does not make sense (at this point) to ever
       make working trees by default. (Robert Collins)
 
+    * The ``lock_write`` method of ``LockableFiles``, ``Repository`` and
+     ``Branch`` now accept a ``token`` keyword argument, so that separate
+     instances of those objects can share a lock if it has the right token.
+     (Andrew Bennetts, Robert Collins)
+
   BUGFIXES:
 
     * Don't fail bundle selftest if email has 'two' embedded.  

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2007-04-11 05:58:16 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2007-04-13 01:57:12 +0000
@@ -16,32 +16,20 @@
 
 """Tests for bzrdir implementations - tests a bzrdir format."""
 
-import os
 import re
-import sys
 
 import bzrlib
 from bzrlib import (
     bzrdir,
     errors,
-    lockdir,
     remote,
     repository,
     )
-from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
 from bzrlib.delta import TreeDelta
-from bzrlib.errors import (FileExists,
-                           NoSuchRevision,
-                           NoSuchFile,
-                           UninitializableFormat,
-                           NotBranchError,
-                           )
 from bzrlib.inventory import Inventory, InventoryDirectory
 from bzrlib.revision import NULL_REVISION
-from bzrlib.repofmt import knitrepo
-from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
+from bzrlib.tests import TestCaseWithTransport, TestSkipped
 from bzrlib.tests.bzrdir_implementations.test_bzrdir import TestCaseWithBzrDir
-from bzrlib.trace import mutter
 from bzrlib.transport import get_transport
 from bzrlib.upgrade import upgrade
 from bzrlib.workingtree import WorkingTree
@@ -442,10 +430,6 @@
 
 class TestRepositoryLocking(TestCaseWithRepository):
 
-    def setUp(self):
-        TestCaseWithRepository.setUp(self)
-        self.reduceLockdirTimeout()
-
     def test_leave_lock_in_place(self):
         repo = self.make_repository('r')
         # Lock the repository, then use leave_lock_in_place so that when we
@@ -567,7 +551,7 @@
         self.assertEqual({'rev1':[],
                           'rev2':['rev1']},
                          self.bzrdir.open_repository().get_revision_graph('rev2'))
-        self.assertRaises(NoSuchRevision,
+        self.assertRaises(errors.NoSuchRevision,
                           self.bzrdir.open_repository().get_revision_graph,
                           'orphan')
         # and ghosts are not mentioned

=== modified file 'bzrlib/tests/test_lockable_files.py'
--- bzrlib/tests/test_lockable_files.py	2007-04-12 08:04:51 +0000
+++ bzrlib/tests/test_lockable_files.py	2007-04-13 01:57:12 +0000
@@ -17,7 +17,6 @@
 from StringIO import StringIO
 
 import bzrlib
-from bzrlib.branch import Branch
 import bzrlib.errors as errors
 from bzrlib.errors import BzrBadParameterNotString, NoSuchFile, ReadOnlyError
 from bzrlib.lockable_files import LockableFiles, TransportLock
@@ -36,9 +35,6 @@
 # these tests are applied in each parameterized suite for LockableFiles
 class _TestLockableFiles_mixin(object):
 
-    def setUp(self):
-        self.reduceLockdirTimeout()
-
     def test_read_write(self):
         self.assertRaises(NoSuchFile, self.lockable.get, 'foo')
         self.assertRaises(NoSuchFile, self.lockable.get_utf8, 'foo')
@@ -320,7 +316,6 @@
 
     def setUp(self):
         TestCaseInTempDir.setUp(self)
-        _TestLockableFiles_mixin.setUp(self)
         transport = get_transport('.')
         transport.mkdir('.bzr')
         self.sub_transport = transport.clone('.bzr')
@@ -343,7 +338,6 @@
 
     def setUp(self):
         TestCaseInTempDir.setUp(self)
-        _TestLockableFiles_mixin.setUp(self)
         self.transport = get_transport('.')
         self.lockable = self.get_lockable()
         # the lock creation here sets mode - test_permissions on branch 
@@ -374,7 +368,6 @@
 
     def setUp(self):
         TestCaseWithSmartMedium.setUp(self)
-        _TestLockableFiles_mixin.setUp(self)
         # can only get a RemoteLockDir with some RemoteObject...
         # use a branch as thats what we want. These mixin tests test the end
         # to end behaviour, so stubbing out the backend and simulating would

